"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _moduleReplication = require("@resolve-js/module-replication");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
const getReplicationState = async ({
  targetApplicationUrl
}) => {
  if (targetApplicationUrl == null || targetApplicationUrl.constructor !== String || targetApplicationUrl.length === 0) {
    return {
      status: 'error',
      statusData: {
        name: 'Error',
        message: 'Invalid target application url: empty or not a string. The replication is no-op'
      },
      paused: false,
      iterator: null,
      successEvent: null
    };
  }

  try {
    const response = await (0, _nodeFetch.default)(`${targetApplicationUrl}${_moduleReplication.REPLICATION_STATE.endpoint}`);
    const state = await response.json();

    if (response.status >= 400) {
      var _message;

      return {
        status: 'serviceError',
        statusData: {
          name: response.statusText,
          message: (_message = state.message) !== null && _message !== void 0 ? _message : response.statusText
        },
        paused: false,
        iterator: null,
        successEvent: null
      };
    }

    return state;
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      const state = {
        status: 'serviceError',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        paused: false,
        iterator: null,
        successEvent: null
      };
      return state;
    } else {
      throw error;
    }
  }
};

var _default = getReplicationState;
exports.default = _default;
//# sourceMappingURL=get-replication-state.js.map